@@ -14,6 +14,8 @@ from PIL import Image
 
 from modlunky2.assets.constants import KNOWN_TEXTURES_V1
 from modlunky2.assets.exc import NonSiblingAsset
+from modlunky2.sprites.sprite_loaders import get_all_sprite_loaders
+from modlunky2.sprites.sprite_mergers import get_all_sprite_mergers
 
 from .chacha import Key, chacha, hash_filepath
 from .constants import (
@@ -27,6 +29,9 @@ from .constants import (
 from .converters import dds_to_png, png_to_dds, rgba_to_png
 from .exc import FileConflict, MissingAsset, MultipleMatchingAssets
 from .string_hashing import StringHashes
+from .hashing import md5sum_path
+
+
 
 logger = logging.getLogger("modlunky2")
 
@@ -265,6 +270,11 @@ class AssetStore:
         except Exception:  # pylint: disable=broad-except
             logger.exception("Failed Extraction")
 
+    @staticmethod
+    def _merge_single_entity(sprite_merger, sprite_loaders):
+        sprite_merger.do_merge(sprite_loaders)
+        sprite_merger.save()
+
     def extract(
         self,
         extract_dir,
@@ -273,6 +283,7 @@ class AssetStore:
         max_workers=max(os.cpu_count() - 2, 1),
         recompress=True,
         generate_string_hashes=True,
+        create_entity_sheets=True,
     ):
         unextracted = []
         for asset in self.assets:
@@ -302,6 +313,24 @@ class AssetStore:
         if generate_string_hashes:
             self.hash_strings(extract_dir)
 
+        if create_entity_sheets:
+            logger.info("Creating entity sprite sheets...")
+            sprite_loaders = get_all_sprite_loaders(extract_dir)
+            sprite_mergers = get_all_sprite_mergers(extract_dir)
+
+            with ThreadPoolExecutor(max_workers=max_workers) as pool:
+                futures = [
+                    pool.submit(
+                        self._merge_single_entity,
+                        sprite_merger,
+                        sprite_loaders,
+                    )
+                    for sprite_merger in sprite_mergers
+                ]
+                wait(futures, timeout=300)
+
+            logger.info("Done creating entity sprite sheets...")
+
         return unextracted
 
     def hash_strings(self, extract_dir):
@@ -556,13 +585,7 @@ class DiskAsset:
             ) from err
 
     def md5sum_of_asset(self):
-        with self.asset_path.open("rb") as file_:
-            md5sum = hashlib.md5()
-            chunk = file_.read(8192)
-            while chunk:
-                md5sum.update(chunk)
-                chunk = file_.read(8192)
-            return md5sum.hexdigest().encode()
+        return md5sum_path(self.asset_path)
 
     @property
     def real_suffix(self):
