@@ -25,7 +25,7 @@ from modlunky2.assets.constants import (
 )
 from modlunky2.assets.exc import MissingAsset
 from modlunky2.assets.patcher import Patcher
-from modlunky2.constants import BASE_DIR, ROOT_DIR
+from modlunky2.constants import BASE_DIR, ROOT_DIR, IS_EXE
 from modlunky2.ui.extract import ExtractTab
 from modlunky2.ui.levels import LevelsTab
 from modlunky2.ui.pack import PackTab
@@ -35,6 +35,9 @@ logger = logging.getLogger("modlunky2")
 
 cwd = os.getcwd()
 
+MIN_WIDTH = 1024
+MIN_HEIGHT = 800
+
 
 def get_latest_version():
     try:
@@ -56,19 +59,30 @@ class ModlunkyUI:
     def __init__(self, install_dir, beta=False):
         self.install_dir = install_dir
         self.beta = beta
-        self.current_version = get_current_version()
-        self.latest_version = get_latest_version()
-        if self.latest_version is None or self.current_version is None:
-            self.needs_update = False
+
+        if IS_EXE:
+            self.current_version = get_current_version()
+            self.latest_version = get_latest_version()
+            if self.latest_version is None or self.current_version is None:
+                self.needs_update = False
+            else:
+                self.needs_update = self.current_version < self.latest_version
         else:
-            self.needs_update = self.current_version < self.latest_version
+            self.current_version = None
+            self.latest_version = None
+            self.needs_update = False
 
         self._shutdown_handlers = []
         self._shutting_down = False
 
         self.root = tk.Tk(className="Modlunky2")  # Equilux Black
         self.root.title("Modlunky 2")
-        self.root.geometry("950x650")
+        self.root.geometry(f"{MIN_WIDTH}x{MIN_HEIGHT}")
+        self.root.minsize(MIN_WIDTH, MIN_HEIGHT)
+        self.root.grid_columnconfigure(0, weight=1)
+        self.root.grid_rowconfigure(0, weight=0)
+        self.root.grid_rowconfigure(1, weight=1)
+        self.root.grid_rowconfigure(2, weight=0)
         # self.root.resizable(False, False)
         self.icon_png = PhotoImage(file=BASE_DIR / "static/images/icon.png")
         self.root.iconphoto(False, self.icon_png)
@@ -77,7 +91,7 @@ class ModlunkyUI:
             update_button = ttk.Button(
                 self.root, text="Update Modlunky2!", command=self.update
             )
-            update_button.pack()
+            update_button.grid(column=0, row=0)
 
         # Handle shutting down cleanly
         self.root.protocol("WM_DELETE_WINDOW", self.quit)
@@ -108,9 +122,10 @@ class ModlunkyUI:
         )
 
         self.tab_control.bind("<<NotebookTabChanged>>", self.on_tab_change)
-        self.tab_control.pack(expand=1, fill="both")
+        self.tab_control.grid(column=0, row=1, sticky="nsew")
 
-        self.console = ConsoleWindow()
+        self.console = ConsoleWindow(self.root)
+        self.console.grid(column=0, row=2, sticky="ew")
 
     def update(self):
         webbrowser.open_new_tab(
